@@ -1,10 +1,10 @@
-from mailqueue.models import MailerMessage
 from django.http import HttpResponse
 
+from mailqueue.models import MailerMessage
+
 def run_mail_job(request):
-    emails = MailerMessage.objects.filter(sent=False)[:30]
-    for email in emails:
-        email.send()
+    MailerMessage.objects.send_queued()
+
     response = HttpResponse()
     response.status_code = 200
     return response
\ No newline at end of file
